/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.caldav.clientfields;


/**
 * {@link Lightning}
 *
 * @author <a href="mailto:firstname.lastname@open-xchange.com">Firstname Lastname</a>
 * @since v7.10.2
 */
public enum Lightning {
    X_MOZ_LASTACK("X-MOZ-LASTACK"),
    X_MOZ_FAKED_MASTER("X-MOZ-FAKED-MASTER"),
    X_MOZ_GENERATION("X-MOZ-GENERATION"),
    X_MOZ_SNOOZE("X-MOZ-SNOOZE"),
    X_MOZ_SNOOZE_TIME("X-MOZ-SNOOZE-TIME"),
    X_LIC_ERROR("X-LIC-ERROR"),
    ;
    
    private final String id;
    
    /**
     * Initializes a new {@link Lightning}.
     */
    private Lightning(String id) {
        this.id = id;
    }
    
    /**
     * Gets the id
     *
     * @return The id
     */
    public String getId() {
        return id;
    }

}
